**Author:** [Behrouz Safari](https://behrouzz.github.io/)<br/>
**License:** [MIT](https://opensource.org/licenses/MIT)<br/>

# instanet
*A python package for analysing Instagram network*


## Installation

Install the latest version of *instanet* from [PyPI](https://pypi.org/project/instanet/):

    pip install instanet

Requirements are *requests*, *networkx* and *matplotlib*.
